Function simple_popup

pub fn simple_popup<Message: 'static>(
    settings: impl Fn() -> SctkPopupSettings + Send + Sync + 'static,
    view: Option<impl Fn() -> Element<'static, Action<Message>> + Send + Sync + 'static>,
) -> Action
Available on crate feature wayland and Linux and crate feature winit only.
Used to create a popup message from within a widget.