Function simple_subsurface

pub fn simple_subsurface<Message: 'static, V>(
    settings: impl Fn() -> SctkSubsurfaceSettings + Send + Sync + 'static,
    view: Option<Box<dyn Fn() -> Element<'static, Action<Message>> + Send + Sync + 'static>>,
) -> Action
Available on crate feature wayland and Linux and crate feature winit only.
Used to create a subsurface message from within a widget.