Function simple_window

pub fn simple_window<Message: 'static>(
    settings: impl Fn() -> Settings + Send + Sync + 'static,
    view: Option<impl Fn() -> Element<'static, Action<Message>> + Send + Sync + 'static>,
) -> (Id, Action)
Available on crate feature wayland and Linux and crate feature winit only.
Used to create a window message from within a widget.